@@ -1,8 +1,7 @@
 use crate::opt::{Command, DatabaseCommand, MigrateCommand};
-use anyhow::{anyhow, bail};
+use anyhow::anyhow;
 use dotenv::dotenv;
 use std::env;
-use std::path::Path;
 
 mod database;
 // mod migration;
@@ -14,13 +13,6 @@ mod prepare;
 pub use crate::opt::Opt;
 
 pub async fn run(opt: Opt) -> anyhow::Result<()> {
-    if !Path::new("Cargo.toml").exists() {
-        bail!(
-            r#"Failed to read `Cargo.toml`.
-hint: This command only works in the manifest directory of a Cargo package."#
-        );
-    }
-
     dotenv().ok();
 
     let database_url = match opt.database_url {
@@ -31,8 +23,16 @@ hint: This command only works in the manifest directory of a Cargo package."#
 
     match opt.command {
         Command::Migrate(migrate) => match migrate.command {
-            MigrateCommand::Add { description } => migrate::add(&migrate.source, &description)?,
-            MigrateCommand::Run => migrate::run(&migrate.source, &database_url).await?,
+            MigrateCommand::Add {
+                description,
+                reversible,
+            } => migrate::add(&migrate.source, &description, reversible).await?,
+            MigrateCommand::Run { dry_run } => {
+                migrate::run(&migrate.source, &database_url, dry_run).await?
+            }
+            MigrateCommand::Revert { dry_run } => {
+                migrate::revert(&migrate.source, &database_url, dry_run).await?
+            }
             MigrateCommand::Info => migrate::info(&migrate.source, &database_url).await?,
         },
 
@@ -45,9 +45,17 @@ hint: This command only works in the manifest directory of a Cargo package."#
             DatabaseCommand::Setup { source } => database::setup(&source, &database_url).await?,
         },
 
-        Command::Prepare { check: false, args } => prepare::run(&database_url, args)?,
+        Command::Prepare {
+            check: false,
+            merged,
+            args,
+        } => prepare::run(&database_url, merged, args)?,
 
-        Command::Prepare { check: true, args } => prepare::check(&database_url, args)?,
+        Command::Prepare {
+            check: true,
+            merged,
+            args,
+        } => prepare::check(&database_url, merged, args)?,
     };
 
     Ok(())
